@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2021 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 
@@ -11,9 +11,7 @@ from dill.source import getimportable
 from dill._dill import IS_PYPY
 
 import sys
-PY3 = sys.version_info[0] >= 3
-IS_PYPY3 = IS_PYPY and PY3
-PY310b = '0x30a00b1'
+PY310b = 0x30a00b1
 
 f = lambda x: x**2
 def g(x): return f(x) - x
@@ -61,14 +59,12 @@ def test_itself():
 
 # builtin functions and objects
 def test_builtin():
-  if PY3: builtin = 'builtins'
-  else: builtin = '__builtin__'
   assert likely_import(pow) == 'pow\n'
   assert likely_import(100) == '100\n'
   assert likely_import(True) == 'True\n'
-  assert likely_import(pow, explicit=True) == 'from %s import pow\n' % builtin
+  assert likely_import(pow, explicit=True) == 'from builtins import pow\n'
   assert likely_import(100, explicit=True) == '100\n'
-  assert likely_import(True, explicit=True) == 'True\n' if PY3 else 'from %s import True\n' % builtin
+  assert likely_import(True, explicit=True) == 'True\n'
   # this is kinda BS... you can't import a None
   assert likely_import(None) == 'None\n'
   assert likely_import(None, explicit=True) == 'None\n'
@@ -87,14 +83,9 @@ def test_dynamic():
 
 # classes and class instances
 def test_classes():
-  try: #XXX: should this be a 'special case'?
-    from StringIO import StringIO
-    y = "from StringIO import StringIO\n"
-    x = y
-  except ImportError:
-    from io import BytesIO as StringIO
-    y = "from _io import BytesIO\n"
-    x = y if (IS_PYPY3 or hex(sys.hexversion) >= PY310b) else "from io import BytesIO\n"
+  from io import BytesIO as StringIO
+  y = "from _io import BytesIO\n"
+  x = y if (IS_PYPY or sys.hexversion >= PY310b) else "from io import BytesIO\n"
   s = StringIO()
 
   assert likely_import(StringIO) == x
